pro plfold,fac,cfile=cfi,norm=norm,weights=weights,eps=eps,wrange=wr,rebin=rebin
; plot spectra folded over phase
; fac  : contrast factor for image (useful for the postsctript output)
get_lun,lun
if n_elements(fac) eq 0 then fac =1
if n_elements(weights) eq 0 then weights=1
if n_elements(cfi) eq 0 then cfi='foldspec'
if n_elements(wr) ne 0 and n_elements(wr) ne 2 then begin
  print,'wr must 2-element array: [wavelength1,wwavelength2]'
  return
endif

openr,lun,cfi
nbin=1
nwo=1
readu,lun,nbin,nwo
trsp=fltarr(nbin,nwo)
pha=fltarr(nbin)
dpha=pha
readu,lun,pha
readu,lun,dpha
w=fltarr(nwo)
wt=fltarr(nbin)
readu,lun,w
readu,lun,trsp
rebin=0
readu,lun,rebin
if rebin then readu,lun,wt
istr=''
readf,lun,istr
close,lun

; if spectra were not rebinned,  plot them sorted by phase
if rebin eq 0 then begin
  phaf=pha mod 1
  ind=where(phaf lt 0.)
  if ind(0) ne -1 then phaf(ind)=phaf(ind)+1
  ind=sort(phaf)
  for i=0,nwo-1 do trsp(*,i)=trsp(ind,i)
endif
i0=0
i1=nwo-1
print,n_elements(wr)
if n_elements(wr) eq 0 then begin 
  wr=[w(0),w(nwo-1)]
endif else begin
  iwr=fix(interpol(indgen(nwo),w,wr))
  i0=max([0,iwr(0)])
  i1=min([nwo,iwr(1)])
endelse
nwo=i1-i0+1
w=w(i0:i1)
trsp=trsp(*,i0:i1)
if keyword_set(norm) then for i=0,nbin-1 do trsp(i,*)=trsp(i,*)/total(trsp(i,i0:i1))
npy=300  ;nominal number of pixels vertical
isy=fix(npy/nbin)   ;factor for stretching in y
npx=800   ;nominal no of pix in x
nlf=max([1,fix(npx/nwo)])
tstr=' '
if rebin eq 0 then tstr='spectra sorted by phase.  '
set_plot, 'x'
loadct,3,/silent
mcol=!d.table_size-1
window,0,xsize=npx,ysize=npy
offs=40
set_plot,'ps'
mcolp=!d.table_size-1 ; max no of colors of display
device,/landscape,font_size=14,bits_per_pixel=8,xsize=30,ysize=30
off=0.1
device,filename='foldspec.ps'
if keyword_set(eps) then device,/encaps else device,encap=0

nbf=2   ; number of repeats in phase
wy=[0,nbf]
nl=nwo
trs=fltarr(nbf*nbin,nl)
; repeat in phase direction
for irep=0,nbf-1 do trs(irep*nbin:irep*nbin+nbin-1,*)= $
  trsp(0:nbin-1,*)

sma=max(trs)
d=rotate((fac*trs/sma>0)<1,4)
n2=2*nbin
if rebin eq 1 then begin
; make weight histogram
  wt=wt/total(wt)*nbin
  xm=0.05
  wm=xm*wr(1)+(1-xm)*wr(0)
  wt=wr(0)+(wm-wr(0))*wt
  xw=findgen(nbin)/nbin
  xw=[xw,1+xw]
  y=[wt,wt]
  xw=[xw,2]
  histo,n2,xw,y,xx,yy
endif

; make `atmosphere subtracted' spectrum
; first get phase-dependence of continuum
ww=w(0.4*nwo:0.6*nwo)
nww=n_elements(ww)
trw=trs(*,0.4*nwo:0.6*nwo)
trb=total(trw,1)/n2
ind=sort(trb)
f=0.25
indf=ind((1-f)*0.5*nww:(1+f)*0.5*nww)
nwf=n_elements(indf)
clev=total(trw(*,indf),2)/nwf             ; this is continuum as fn of phase
cla=total(clev)/n2
trsc=trs
for i=0,nl-1 do trsc(*,i)=trs(*,i)/clev   ; spectrum divided by phase-dependence
tra=total(trsc,1)/n2                    ; phase-average minus continuum
df=rotate((fac*trsc*cla/sma>0)<1,4)
for i=0,n2-1 do trsc(i,*)=trsc(i,*)-tra+1  ; phase avg subtracted, contin added

set_plot,'x'
if rebin eq 1 then yty=5 else yty=4
plot,wr,3*wy,/nodata,/device,xra=wr,yra=3*wy,xsty=5,ysty=yty
px=!x.window*!d.x_vsize
py=!y.window*!d.y_vsize
sx=px(1)-px(0)+1
sy=py(1)-py(0)+1
tv,congrid(d*mcol,sx,sy/3),px(0),py(0)
tv,congrid((1-d)*mcol,sx,sy/3),px(0),sy/3+py(0)
tv,congrid(df*mcol,sx,sy/3),px(0),sy*2./3+py(0)
plot,wr,3*wy,/nodata,/device,title=tstr+istr,xra=wr,yra=3*wy,$
  xsty=1,ysty=yty,/noerase
if weights eq 1 and rebin then oplot,yy,xx
set_plot,'ps'
xsiz=0.7
ysiz=0.3
plot,wr,wy,position=[0,off,xsiz,ysiz+off],psym=3,xsty=5,ysty=yty,$
  xtitle='waveln',ytitle='phase',title=tstr+istr
yl=!y.window(1)-!y.window(0)
xl=!x.window(1)-!x.window(0)
tv,mcolp*d,!x.window(0),!y.window(0),$
  xsize=xl,ysize=yl/3,/norm
tv,mcolp*(1-d),!x.window(0),!y.window(0)+yl/3,$
  xsize=xl,ysize=yl/3,/norm
tv,mcolp*df,!x.window(0),!y.window(0)+yl*2./3,$
  xsize=xl,ysize=yl/3,/norm
;tv,mcolp*(1-dr),!x.window(0),!y.window(0)+yl*0.75,$
;  xsize=xl,ysize=yl/4,/norm
plot,wr,wy*3,position=[0,off,xsiz,ysiz+off],psym=3,xsty=1,ysty=yty,$
  /noerase
if weights eq 1 and rebin then oplot,yy,xx,color=0

device,/close_file

set_plot,'x'
return
end

